Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: content/public/common/file_chooser_params.h

Issue 18627002: Change dialog texts for folder upload to explicitly indicate it's for 'Uploading' (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/common/file_chooser_params.h
diff --git a/content/public/common/file_chooser_params.h b/content/public/common/file_chooser_params.h
index 7e4f2bd6fcb624aff932674d86025b8bd7770724..b94d4cea23a519b4b404968d3b7c49326ca3b8a5 100644
--- a/content/public/common/file_chooser_params.h
+++ b/content/public/common/file_chooser_params.h
@@ -25,8 +25,8 @@ struct CONTENT_EXPORT FileChooserParams {
// Like Open, but allows picking multiple files to open.
OpenMultiple,
- // Like Open, but selects a folder.
- OpenFolder,
+ // Like Open, but selects a folder for upload.
+ UploadFolder,
// Allows picking a nonexistent file, and prompts to overwrite if the file
// already exists.

Powered by Google App Engine
This is Rietveld 408576698